==> lxqt-panel-2.1.2.tar.xz: lxqt-panel-2.1.2/plugin-desktopswitch/translations/desktopswitch_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="95"/>
        <source>Switch to desktop %1</source>
        <translation>Switch to desktop %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="170"/>
        <location filename="../desktopswitch.cpp" line="181"/>
        <source>Desktop %1</source>
        <translation>Desktop %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>DesktopSwitch Settings</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="342"/>
        <source>n/a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="344"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-desktopswitch/translations/desktopswitch_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="95"/>
        <source>Switch to desktop %1</source>
        <translation>Switch to desktop %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="170"/>
        <location filename="../desktopswitch.cpp" line="181"/>
        <source>Desktop %1</source>
        <translation>Desktop %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch Settings</source>
        <translation>DesktopSwitch Settings</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Number of rows:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Desktop labels:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Appearance</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Numbers</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Names</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>If checked, widget will be just an indicator</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Show only active desktop</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Desktop names</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="78"/>
        <source>Desktop %1:</source>
        <translation>Desktop %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.cpp" line="342"/>
        <source>n/a</source>
        <translation>n/a</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="344"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation>DesktopSwitch is unsupported on current platform: %1</translation>
    </message>
</context>
</TS>
